---
jupyter:
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
---

# Jupyter notebook

This notebook is a simple jupyter notebook. It only has markdown and code cells. And it does not contain consecutive markdown cells. We start with an addition:

```{python}
a = 1
b = 2
a + b
```

Now we return a few tuples

```{python}
a, b
```

```{python}
a, b, a+b
```

And this is already the end of the notebook
